@@ -9,14 +9,10 @@
 
 """Override of RecordResources."""
 
-from .config import RecordResourceConfig, RecordVersionsResourceConfig
-from .resource import RecordResource, RecordVersionsResource
-from .schemas_links import RecordLinksSchema
+from .config import RecordResourceConfig
+from .resource import RecordResource
 
 __all__ = (
-    "RecordLinksSchema",
     "RecordResource",
     "RecordResourceConfig",
-    "RecordVersionsResource",
-    "RecordVersionsResourceConfig",
 )
